package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@("`0D````````````"`"L````!```````0'*``````````0```````
M`,A``````@!``#@`!@!``!D`&`````8````%`````````$```````!``0```
M````$`!``````````5`````````!4``````````(`````P````0````````!
MD```````$`&0```````0`9``````````%0`````````5``````````$````!
M````!0`````````````````0`````````!```````````%OW````````6_<`
M`````!````````$````'````````8````````"!@````````(&``````````
M9B@```````!K(```````$````````@````8```````"[R```````(+O(````
M```@N\@````````"$`````````(0``````````@````$````!`````````&H
M```````0`:@``````!`!J``````````8`````````!@`````````!"]L:6)E
M>&5C+VQD+65L9BYS;RXQ``````````@````$`````49R965"4T0```PXZ```
M`&$```!K`````````#X`````````"P````````!A````8````%L`````````
M`````&D`````````2````%\`````````.0```$(````\````$````#@```!,
M````4P```$D````````````````````C````7````#`````#`````````#,`
M``!5````+@```&4`````````"````!P```!F````'0`````````L````````
M`&0`````````+P```&,`````````3@```"H````'````40```&@```!`````
M10```"<```!8````70```&H`````````,@```"(`````````2P``````````
M``````````````!4````1P```#8```!:````8@```"``````````````````
M``!9````-````$,```!7````7@````\`````````$0````8`````````````
M```````Z`````````"$````5`````````"T```!G````````````````````
M````````````````````````````````````````````````````````````
M``````````X`````````````````````````````````````````````````
M```````````````````3````!0```!L````*```````````````-````````
M````````````````````````````````````````````*P`````````?````
M``````P````D`````````"8`````````````````````````!```````````
M```````````````W````````````````````/P``````````````$@``````
M````````.P``````````````)0```!X````)````*0````````!$````*```
M`!D`````````00`````````]````4````#$``````````````#4````8````
M3P```!H```!&`````````!0`````````%P```%8```!2``````````````!-
M````%@````````!*`````````````````````````````````````!T`````
M`````````@```````````````!T``````````````P``````````````#!(`
M`````````""^@``````````P```#$Q(``````````""^H``````````X````
M%Q(``````````""^P`````````EL````*1$``!8``````"#&,``````````!
M```#L!(``````````""^X``````````L```$!!(```L``````!`^P```````
M``&T````0!$`__$``````""[R``````````````#)A(``````````""_````
M```````D```#,Q(``````````""_(`````````!H```#;!(``````````""_
M0``````````X````21(``````````""_8`````````%`````5Q(`````````
M`""_@`````````$@````8Q(``````````""_H`````````#@```$$1(```L`
M`````!!28``````````0````=!$``!8``````"#&.``````````(```"M!$`
M`!8``````"#&0`````````!`````?A(``````````""_P`````````P8````
MC1$``!8``````"#&@``````````(```$(A(```L``````!`X0`````````!@
M````EQ(``````````""_X`````````0H```$,!(```L``````!!`P```````
M``%<```#>A(``````````"#````````````(````I1$`__$``````""^````
M```````````#2A(``````````"#`(`````````]0````OQ$``!8``````"#&
MB``````````!```$81(```H``````!`<:```````````````S!(`````````
M`"#`0`````````<,````UQ(``````````"#`8`````````"D````Y!(`````
M`````"#`@`````````%0````\A$``!8``````"#+&``````````(````^A(`
M`````````"#`H`````````+T```#.Q(``````````"#`P`````````!\```#
M0Q(``````````"#`X``````````D```$/!(```L``````!!%0`````````'L
M```!!1(``````````"#!```````````4```$21(```L``````!!2@```````
M``-(```$7Q(```L``````!!5X``````````H```#91(``````````"#!(```
M```````H```#&Q$```X``````"!@```````````(```#TA(```L``````!`<
MH`````````#8```#HA(``````````"#!0``````````D```#)Q(`````````
M`"#!8``````````D```#A!(``````````"#!@``````````4```#<Q(`````
M`````"#!H`````````#<```$9Q(```L``````!!'0`````````HP```!%!(`
M`````````"#!P`````````8$```"[A(``````````"#!X``````````D```"
M:!(``````````"#"``````````!0```"_!(``````````"#"(``````````T
M```$=!(```L``````!!"(`````````!L```#+!(``````````"#"0```````
M``"````!'1$``!8``````"#&B0`````````!```#C!(``````````"#"8```
M``````!@```!*Q(``````````"#"@`````````($```!.Q$``!8``````"#&
MD``````````(```#S1``__$``````"#&*``````````````">A(`````````
M`"#"H`````````!0```$@!(```L``````!!"H`````````*,```$A1(```L`
M`````!`]H`````````$8```"BA$``!8``````"#&F``````````$```$EQ(`
M``L``````!!1@`````````#$```!2Q$``!8``````"#&G``````````!```!
M5A(```P``````!!6P``````````````!7!(``````````"#"P````````")L
M```$Z!(``````````"#"X``````````T```#4A$``!8``````"#&H```````
M```(```"=1(``````````"##``````````"````"K!(``````````"##(```
M``````(4```!:A(``````````"##0``````````D```#G1(``````````"##
M8`````````!8```#P!(``````````"##@``````````D```")A(`````````
M`"##H`````````78```!>A(``````````"##P`````````!(```#QA``__$`
M`````"#&*``````````````"S1(``````````"##X`````````(4```!A1$`
M__$``````"#&(``````````````#V1``__$``````"#+(``````````````"
M]!(``````````"#$``````````!<```!FQ$``!8``````"#&J``````````!
M```!IA$``!8``````"#&L``````````3```"U!$``!8``````"#&R```````
M```(```",A(``````````"#$(`````````1````"YQ(``````````"#$0```
M```````D```$K1(```L``````!`XH``````````D```!M1(``````````"#$
M8`````````"D```#`A(``````````"#$@``````````H```$R1(```L`````
M`!`>8`````````!,```!S!$``!8``````"#&T``````````(```#FQ(`````
M`````"#$H``````````L```$UA(```L``````!!`@``````````D```"F!(`
M`````````"#$P``````````H```!TA$``!8``````"#&V``````````(```"
MQA(``````````"#$X``````````D```!W1(``````````"#%``````````,8
M```!ZQ$``!8``````"#&X``````````(```#J1(``````````"#%(```````
M``&8```#MQ(``````````"#%0`````````"@```"<!(``````````"#%8```
M``````!8```!^"`````````````````````````````#DQ(``````````"#%
M@``````````X```"#!(``````````"#%H`````````!````"WA(`````````
M`"#%P``````````D```"&A(``````````"#%X`````````!0```"+1(`````
M`````"#&``````````!``&QI8G!E<FPN<V\`4&5R;%]C<F]A:P!097)L7W-V
M7S)P=E]F;&%G<P!03%]P97)L7V1E<W1R=6-T7VQE=F5L`%]$64Y!34E#`%!E
M<FQ?879?<VAI9G0`4&5R;%]M9U]S970`4&5R;%]N97=84U]F;&%G<P!03%]C
M;VUP8W8`<&5R;%]C;VYS=')U8W0`4$Q?<&%R<V5R`%!E<FQ?9&]U;G=I;F0`
M7U!23T-%1%5215],24Y+04=%7U1!0DQ%7P!03%]D;U]U;F1U;7``<&5R;%]P
M87)S90!097)L7VYE=U-6<'8`4&5R;%]S=E]S971P=@!E;G9I<F]N`%!E<FQ?
M;F5W6%,`4&5R;%]S>7-?:6YI=#,`<&5R;%]R=6X`4$Q?97AI=%]F;&%G<P!B
M;V]T7T1Y;F%,;V%D97(`4$Q?8W5R<W1A8VMI;F9O`%!,7W1A:6YT960`7V9I
M;FD`<&5R;%]D97-T<G5C=`!097)L7V=V7V9E=&-H<'8`<&5R;%]A;&QO8P!?
M1TQ/0D%,7T]&1E-%5%]404),15\`4$Q?:6Y?979A;`!03%]M96UO<GE?=W)A
M<`!097)L7W-A=F5?9&5S=')U8W1O<E]X`%!,7V]P`%!,7W1O<%]E;G8`4&5R
M;%]A=E]F971C:`!03%]E=F%L7W)O;W0`7TIV7U)E9VES=&5R0VQA<W-E<P!0
M97)L7W-Y<U]T97)M`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V9R964`;&EB
M;2YS;RXU`&QI8F-R>7!T+G-O+C4`;&EB=71I;"YS;RXX`&QI8G1H<BYS;RXS
M`%]?97)R;W(`<F5A9`!O<&5N`&-L;W-E`&QI8F,N<V\N-P!?7VUB7W-B7VQI
M;6ET`%]?<W!A<F-?=71R87!?<V5T=7``;65M;6]V90!?7W-T86-K7V-H:U]G
M=6%R9`!G971P:60`;65M8W!Y`%]?<W1D97)R<`!R96%D;&EN:P!G971U:60`
M<FUD:7(`<F5A9&1I<@!L<V5E:P!?7W-T86-K7V-H:U]F86EL`&9P<FEN=&8`
M7U]P<F]G;F%M90!L<W1A=`!S=')S='(`<W1R;F-M<`!S=')N8W!Y`'5N;&EN
M:P!R96%L;&]C`%]#=7)R96YT4G5N94QO8V%L90!S=')T;VL`<W1R9'5P`&UE
M;7-E=`!?:6YI=%]T;',`;W!E;F1I<@!S=')C;7``<W!R:6YT9@!A=&5X:70`
M86-C97-S`'-T<FQE;@!E>&5C=G``8VQO<V5D:7(`;6MD:7(`7V5D871A`%]?
M8G-S7W-T87)T`%]E;F0`+W5S<B]L;V-A;"]L:6(O<&5R;#4O-2XQ-"XR+VUA
M8V@O0T]210!P87)?:6YI=%]E;G8`<&%R7V-U<G)E;G1?97AE8P!P87)?96YV
M7V-L96%N`'!A<E]D:7)N86UE`'!A<E]F:6YD<')O9P!84U]);G1E<FYA;'-?
M4$%27T)/3U0`>'-?:6YI=`!P87)?;6MT;7!D:7(`<&%R7V-L96%N=7``;6%I
M;@!P87)?<V5T=7!?;&EB<&%T:`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`6%-?
M26YT97)N86QS7U!!4E]#3$5!4E-404-+`'!A<E]B87-E;F%M90!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!&0E-$7S$N,`!&0E-$<')I=F%T95\Q+C``
M`````````````@```````@`!``$``@`"``(``````````0````(```````$`
M```!``(``0`"`````0`````````!`````@`"``$````!``$``@`!``$``@`"
M``(``@`!`````@`#``(``0`"`````@```````0`#``$``0`"``$````!````
M`@`"``,``@````(``@`"`````0`"``$``0`"```````"``(``@`!`````@`!
M`````@`!``0````"```````"``(``P````(````"```````!``$```)<````
M$````"`'>BBP`````P``!/$```````$``@```H`````0``````\>^J`````$
M```$^@```!`'>BBP`````@``!/$````````````@QC`````&````$P``````
M```````````@QC@````1````$P`````````````````@QD`````2````$P``
M```````````````@QH`````4````$P`````````````````@QH@````;````
M$P`````````````````@QHD````V````$P`````````````````@QI`````Y
M````$P`````````````````@QI@````^````$P`````````````````@QIP`
M``!`````$P`````````````````@QJ````!$````$P`````````````````@
MQJ@```!1````$P`````````````````@QK````!2````$P``````````````
M```@QL@```!3````$P`````````````````@QM````!:````$P``````````
M```````@QM@```!>````$P`````````````````@QN````!A````$P``````
M```````````@OH`````#````%0`````````````````@OJ`````$````%0``
M```````````````@OL`````%````%0`````````````````@ON`````'````
M%0`````````````````@OP`````*````%0`````````````````@OR`````+
M````%0`````````````````@OT`````,````%0`````````````````@OV``
M```-````%0`````````````````@OX`````.````%0`````````````````@
MOZ`````/````%0`````````````````@O\`````3````%0``````````````
M```@O^`````6````%0`````````````````@P``````8````%0``````````
M```````@P"`````:````%0`````````````````@P$`````=````%0``````
M```````````@P&`````>````%0`````````````````@P(`````?````%0``
M```````````````@P*`````A````%0`````````````````@P,`````B````
M%0`````````````````@P.`````C````%0`````````````````@P0`````E
M````%0`````````````````@P2`````H````%0`````````````````@P4``
M```K````%0`````````````````@P6`````L````%0`````````````````@
MP8`````M````%0`````````````````@P:`````N````%0``````````````
M```@P<`````P````%0`````````````````@P>`````Q````%0``````````
M```````@P@`````R````%0`````````````````@PB`````S````%0``````
M```````````@PD`````U````%0`````````````````@PF`````W````%0``
M```````````````@PH`````X````%0`````````````````@PJ`````[````
M%0`````````````````@PL````!"````%0`````````````````@PN````!#
M````%0`````````````````@PP````!%````%0`````````````````@PR``
M``!&````%0`````````````````@PT````!'````%0`````````````````@
MPV````!(````%0`````````````````@PX````!)````%0``````````````
M```@PZ````!*````%0`````````````````@P\````!+````%0``````````
M```````@P^````!-````%0`````````````````@Q`````!0````%0``````
M```````````@Q"````!4````%0`````````````````@Q$````!5````%0``
M```````````````@Q&````!7````%0`````````````````@Q(````!8````
M%0`````````````````@Q*````!;````%0`````````````````@Q,````!=
M````%0`````````````````@Q.````!?````%0`````````````````@Q0``
M``!@````%0`````````````````@Q2````!B````%0`````````````````@
MQ4````!C````%0`````````````````@Q6````!D````%0``````````````
M```@Q8````!F````%0`````````````````@Q:````!G````%0``````````
M```````@Q<````!H````%0`````````````````@Q>````!I````%0``````
M```````````@Q@````!J````%0``````````G>._0$```&4!````0``.>P$`
M``"!Q^`(@>@```````````````````````````````````````"=X[]`Q`8@
M!(8&(!"0$``9I`8@"*,XH`"`H*``@RQP`P4`"#*@`,`!!$``%>!PHQC&7B`(
M`L#`$@D`"!C&<2``Q`C``(4HH!B`H*```D``#(8`X`&%.*`8PED@`("@H"^#
M9$`#PG$@`,0(P`"%**`8@*"@`!)/__B&`.`!`P`(+H(08\@"P$`/`0```$`$
M*=T!````$0`$%4`$*=J0$B+`?___R@$```"0$``1DA``$D``"524$``00`0I
M@I$Z(`!`!"G8`0```$`$**8!````$&__\A$`!!4!`````0```)WCOT`C``@Q
MP@QBZ("@8``20``/(0`(&,)<(!#$6$``(L"`"H(0(`&"`&`(G\"``,)T(!#"
M7"`0Q%A```KXO_R"`&`(@A`@`<(L8NB!S^`(`0```#!H``,!`````0```)WC
MOT"!S^`(`0```#!H``4!`````0````$````!````G>._0`,`""_$6&'X`L"`
M")`08?@#````@A!@``+`0`0!````G\!```$```"!S^`(`0```#!H``,!````
M`0```)WCOT"!S^`(`0```#!H``4!`````0````$````!````Q`H``(<HH!B`
MH.```D``#H@0``@#``06D`(@`<188Y#*2(``Q`H``(,XX!B`H$`%ARB@&(ED
M0`B`H.``$D__^I`"(`&!P^`(D!``!#!H``4!`````0````$````!````G>.[
M`+@'I6^"$#__\'>H?X8&(#B($``<BS!P(+H'I>_"6,``A3!P((((0`7"<2`(
MA`B`!<1Q``"(`2`0@*$`'1)O__B&`.`(@A`__[H'(FBO,'`@B@>EU\190`#"
M67_8R%E_J((80`+&67^8@AA`!((80`.%,'`?@@!``800@`&$"(`7Q'%@&(H!
M8`B`H4`=,F__\\190`#"7ZA_'Q:@GB<;MGK$7ZA_GA/AF:84XZ'"6$``\%^E
MI\)WH[>),'`;]EB@"+`&``_&6*`@A2AP!<)?J'^($0`"Q%^H?X@)`!?X6&`0
MPE^E;\I8H!BZ#P`;A@#``<)?I7>&`,`/A"E`&]A?I;^&`,`$R%^CMXH!0`'"
M7Z5_A!"`'8H!0`^T+P`$A@#``OI?I8>)+O`>N`<``<)?H[>W-O`"A@C`%]1?
MI=>V%L`$N@=`#]!?I>^V#L`7N`<`#^1?I@>$#L`!LB[``^A?IA>$$(`:N@=`
M&_9?I8^#*/`%B@%``L1?H[>),/`;M@;`#^I?IA^($0`!F`,`#X@)`!>4`H`/
M@S"P`HH!0`2%*+`>B@E`%X(00`*0`@`/@@A`%Z0$@`^T",`!FBA`!8DI<`6R
M%D`:]%^EGX4Q<!NX!P`9A!"`!+8&P`'(7Z67@RCP'H0(@!>',/`"N`<``H80
MP`&X#P`7A@C`%X@!``^R"4`#EBC`'(4O,`6:$T`9\E^EKX,W,!NZ!T`-VE^E
MMX(00`*(`0`#A2EP'H((0!>+,7`"N@=``8H10`*Z#T`7B@E`%[0&@`^&#P`%
MDBE`'84O<`66$L`#@S=P&[8&P`O67Z7/@A!``K0&@`7*7Z7'A2\P'H((0!>Y
M-S`"M@;``;@7``*V#L`7N`\`%[(&0`^&#T`<H"\`&X4N\`62$D`#@S;P&X@!
M``G27Z7G@A!``K`&`!SX7Z7?A2]P'H((0!>[-W`"B`$``;H70`*("0`7N@]`
M%YH#0`^&#L`=HB]`!(4I,`6@%``#@S$P&[0&@!#@7Z7_@A!``K(&0!WZ7Z7W
MA2[P'H((0!>W-O`"M`:``;86P`*T#H`7M@[`%XH!0`^&"0`;E@+`#X4NL`6B
M%$`#@S:P&[`&`!'B7Z8/@A!``K@'``^%*3`>@@A`%XDQ,`*P!@`!B!$``K`.
M`!>("0`7D@)`#X8.@`2Z!T`/A2XP!:`$``^#-C`;GB[`&IX3P`."$$`"QE^F
M+[(&0`^""$`7WE^F)X4NL!Z&`,`3QG>E3[(&0`'"7Z8WF@-`&[4VL`*R#D`7
MM!:``H(`0!/"=Z4_M`Z`%[8I`!B&#@`:F`,`!(4N<`6V%L`#@S9P&YH#0!N"
M$$`"B"Z`&8((0!>*`4`:]%^F/YH#0`'"7Z9'H@1`$X4N,!Z:"T`7@@!`$\)W
MI1^H!0`3PE^F3[$V,`*J!4`3L!8``IX#P!.P#@`7@@!`$\)WI0^&#D`8MBX`
M#84K<`6($0`#@S-P&Y@#``2"$$`"E@+`&/!?IE>""$`7M`:`$Y@#``'"7Z9?
ML`8`$X4N<!Z8"P`7LS9P`H(`0!/"=Z3OPE^F9[(60`*%*S`%L@Y`%X(`0!.&
M"T`9PG>DWX,S,!NV%L`#@A!``HH!0!N""$`7B"Y`#(H!0`'"7Z9WE`*`&84K
M<!Z*"4`7\E^F;YLS<`*"`$`3PG>DS\)?IG^:$T`"L@9`$X4I<`6:"T`7@@!`
M$X8+``W"=Z2_@S%P&X@1``."$$`"E@+`!(((0!>V*T`%E@+``<)?IH^X!P`-
MA2LP'I8*P!?:7Z:'F3,P`H(`0!/"=Z2OPE^FEY@3``*:`T`3A2KP!9@+`!>"
M`$`3A@E`#,)WI*>#,O`;MA;``X(00`*4`H`;@@A`%X@K``N4`H`!PE^FIY("
M0`S87Z:?A2EP'I0*@!>+,7`"@@!`$\)WI)^8`P`3BA%``N9?IJ\#(\;OB@E`
M%X(08-R&"L`%A2JP!:8$P`&#,K`;B!$``X(00`*X!P`$Q%^FMX((0!<'(\;O
MAA#@W+@'``'"7Z:_A`"``\1WI)>X#P`7A2KP'H(`0`/"=Z2/ES+P`L)?IL>V
M*4`*EA+``I`"``66"L`7@@!``\)WI(>&"H`+B"K`'+86P`,'(\;OA2\P!9("
M0!OV7Z;/@S<P&X80X-R"$$`"!2/&[X((0!>$$*#<M@;``I("0`'"7Z;?A2JP
M'KH'0`O67Z;7E3*P`I(*0!>4$H`"@@!``\)WI'^4"H`7E@+``X4J<`6&#P`*
M@S)P&X@1``."$$`"D`(`!(((0!<)(\;OD`(``<)?IN^($2#<A2\P'I`*`!>"
M`$`$PG>D=XHJ@`G"7Z;WN3<P`J`$``JX%P`"U%^FY[@/`!>"`$`$PG>D;X8*
M0!R4`H`$A2HP!8H10`.#,C`;N@=`!8(00`('(\;O@@A`%X@O``BZ!T`!PE^G
M!X80X-RD!(`<!2/&[_A?IO^"`$`#A!"@W,)WI&>X!P`"PE^G#[H/0!>%*G`>
MDS)P`H(`0`/"=Z1?@S=P&Y(20`*%+W`%D@I`%X8*``F"$$`"B!$``X((0!>@
M!``$"2/&[Z`$``'"7Z<?B!$@W(4J,!Z@#``7@@!`!,)WI%>**D`=PE^G)Y$R
M,`*B!$`)D!(``M)?IQ>0"@`7@@!`!,)WI$^&#T`(J`4`"(4L,`6*$4`#@S0P
M&Z0$@`7*7Z<O@A!``L1?IS<',IBP@@A`%X80X=:D!(`!PE^G/X0`@`3$=Z1'
MA2]P'J0,@!>"`$`$PG>D/Y("0`3"7Z='NS=P`HH!0`2Z%T`"N@]`%X(`0`3"
M=Z0WA2RP!9`?0`B#-+`;D!H`$((00`*B!$`(T%^G3X((0!>J!4`=A2PP'J($
M0`'"7Z=7H30P`J(,0!>@%``"@@!``\)WI"^@#``7D`(``X4L<`6Z'``=@S1P
M&[H?0!*"$$`"J`4`'<1?IV>""$`7G@/`$/I?IU^H!0`!PE^G;X0`@`/$=Z0G
MA2RP'J@-`!>"`$`#PG>D'[H'0`/"7Z=WI32P`J04@`*"`$`#PG>D%Z0,@!?"
M7Z5/A2TP!:`<@!"@'``1B`!`$JH%0!#@7Z=_@S4P&X(00`+$7Z>'H`0``X((
M0!>$`(`#J@5``<1WI`_"7Z>/A2QP'JH-0!>C-'`"@@!``Z(40`+"=Z0'Q%^E
M/Z(,0!?"7Z>7I!Q`$H0`@!'$=Z4WI!R`%((`0`/"=Z/_G@/`$H4M<`7D7Z>?
M@S5P&X(00`+$7Z>GI`2``X((0!>>`\`!PE^GKX0`@`/$=Z/WA2TP'IX+P!>I
M-3`"@@!``\)WH^_"7Z>WJ!4``H4K\`6H#0`7@@!``Z(=`!'"=Z/G@S/P&Z(<
M0!6"$$`"B`$`$<1?I\>""$`7M`:`%.)?I[^(`0`!PE^GSX0`@`/$=Z/?A2UP
M'H@)`!>"`$`#PG>CUZ($0`/"7Z?7JS5P`JH50`+(=Z5G@@!``\)WH\^J#4`7
MPE^E'X4I,`6H'4`4J!T`#X(`0!7"=Z47@S$P&\A?I3>"$$`"Q%^GYZ@!`!3H
M=Z4O@@A`%^A?I]^)*_`>A`"``\1WH\>?,_`"Q%^E+Z@%``.>$\`$G@O`%\A?
MI6>"`(`!JAO`%8((0!?"=Z57JAU`!,9?I5>#,'`;M`:`%84H\`6'*3`>@A!`
M`L1?I0^""$`7A`"`#\1WI0>T!H`!A3$P`K0.@!>#-K`;A!"``\1WI2?&7Z4G
MA2ZP!8(00`+$7Z57B`C`%\9?I1>""$`7GAD`#[`&``2>&\`"A`#`#]Y?I5>"
M`(`!AROP'JH(0!>%,_`"@S5P&X80@`.%+7`%G@C`%\9?I0>(&\`$@A!``H09
M`!J""$`7Q'>D]X0`P`+(7Z3OARZP'H(`@`&""$`7PG>E7X@!``^U-K`"R'>D
MYX,P<!NT%H`#QE^E7[0.@!?(7Z3?A2CP!88>@`_>7Z5?@A!``H08P!6""$`7
ML`8``H<M<!ZP!@`!A35P`K`.`!>(`0`:AA"``\AWI->%+C`%B`C`%X,V,!NT
M&0`:@A!``L1?I.>T'H`/AROP'H((0!>T`(`:L@9`!(4S\`*"!H`!AA"``ZH(
M0!>%+7`%G@C`%X,U<!N&&\`$R%^DSX(00`*$&,`8QE^DUX((0!>(`0`/R'>D
MQX0`P`*'+C`>@@"``;$V,`*T"$`7A2ZP!;`6``.#-K`;L`X`%X8>``^"$$`"
MWE^DOX08P!6""$`7L@9``IX#P!C>=Z2WA35P`K(&0`&'+7`>L@Y`%X,V<!N&
M$(`#A2YP!8@(P!>P&0`8@A!``L1?I,>P'@`:@@A`%[``@!B:`T`$A3:P`H(&
M``&'+K`>G@A`%X,S\!N&$(`#A2OP!;0(P!>&'H`$@A!``LA?I*^$&,`9QE^D
MMX((0!>J`0`:A`#``H<N<!Z"`(`!LS9P`K`(0!>%+C`%LA9``X,V,!NR#D`7
MAAY`&H(00`*$&,`/@@A`%X<K\!Z:`T`"Q%^DIYH#0`&T`(`9F@M`%X4S\`*#
M,W`;AA"``X4K<`6(",`7LAD`&8(00`*R'D`8@@A`%X0%0!F8`P`$ARXP'H(`
M@`&%-C`"G@A`%X,S\!N&$(`#A2OP!;`(P!>&'@`$@A!``H08P`W&7Z2?@@A`
M%X0&@`*T`,`8@@"``8<K<!Z("$`7FS-P`H4I,`6:$T`#@S$P&YH+0!>&&T`8
M@A!``H08P`^""$`7F`,``J8$P`V%,_`"F`,``8<K\!Z8"P`7WE^DCX,S,!N&
M$(`#A2LP!88(P!>:&,`-@A!``IH;0`2""$`7A2DP'K(&@`V),3`"@@9``801
M``+(7Z27M`A`%[((@!>"%D`#L`$``X(+``&&#D`#@A!``YH#P!F'+K`%I@3`
M`8DK,!Z%-K`;F3,P`H00@`.8$P`$A`B`%Y@+`!>F!,`"Q%^DAX(3`!FF#,`7
MA@L`&8(.@`&J`(`,@A!``X4T\!NR!@`!ARSP!8DNL!Z$$(`#@S:P`H0(@!>&
M$$`$@@9``K((P!>>"$`7@A9`#)@.0`R'*_`%@@S``84S\!N"$$`,B2SP'H00
M@`.G-/`"@@-``80(@!>F%,`$I@S`%X(`0`*:"$`7@A3`&88,P!F""\`!@A!`
M`[8&P!F'*W`%F`5``84S<!N6`L`3B2OP'H00@`.#,_`"A`B`%]Y?I&^&$$`$
M@@,``I@(P!>R"$`7QE^D?XDK<!Z"$P`3@@M``:8+`!."$$`3M`#`#(4V<!NV
M!L`!@S-P`H<N<`6"$$`$F@A`%X00@`."$T`,A`B`%X8+0`RV!L`"@@Y``;8.
MP!>"$$`#E`*`#8<N\`66`L`!B2YP'H4V\!N#-G`"A!"``X(00`2$"(`7R%^D
M=Y@(0!>6`L`"@A,`#98*P!>&"P`-@@[``84R\!N"$$`#ARKP!;(!``R$$(`#
M@@:``8DN\!Z$"(`7MS;P`H(`0`*V%L`$F@A`%XDJ\!ZV#L`7@A;`#(8.P`R"
M"L`!M`/`&]Y?I%>%,W`;@A!``Y<R\`*4`H`!ARMP!982P`2$$(`#E@K`%X0(
M@!>"$L`;E`*``K8*P!N4"H`7@@M``8(00!NX!P`+ARJP!;`&0`&%,K`;B2MP
M'H00@`.#,W`"A`B`%X800`2"!@`"Q%^D9YH(P!>P"$`7@A-`"[8`@`V6"T`+
M@@J``8<N,`6"$$`+A38P&X(&@`&)*K`>A!"``Y4RL`*$"(`7E!*`!((`0`+(
M7Z1?E`J`%Y@(0!>"$H`-A@J`#8(.``&T`0`*A3,P&X(00`.)+C`>N`<``8<K
M,`6#-C`"A!"``X(00`2$"(`7F@A`%[@'``*"$T`*N`\`%Y0+0`J""P`!@A!`
M"I("0`V'+S`%I@;``84W,!N)*S`>A!"``X,S,`*$"(`7AA!`!(($P`*8",`7
MI@A`%X(3``V&"P`-@@\``;8#P`S>7Z0_A33P&X(00`.'+/`%@@:``8DO,!Z$
M$(`#N3<P`H0(@!>X%P`$@@!``L1?I$^X#P`7E`A`%X(7``R&#P`,@@S``;0`
M@!R)+/`>@A!``X4RL!N2`D`!ARJP!8,T\`*$$(`#@A!`!(0(@!>8"$`7D@)`
M`H(3`!R2"D`7N`L`'((*@`&"$$`<B@%`#(<J<`66!L`!A3)P&XDJL!Z$$(`#
M@S*P`H0(@!>&$$`$@@+``LA?I$>4",`7E@A`%X(2@`R&"H`,@@I``;@!``J%
M,O`;@A!``X<J\`6"!H`!B2IP'H00@`.3,G`"A`B`%Y(20`2"`$`"D@I`%Y@(
M0!>"$D`*A@I`"H(*P`&V`\`)WE^D)X4S,!N"$$`#B2KP'HH!0`&'*S`%@S+P
M`H00@`."$$`$A`B`%Y0(0!>*`4`"Q%^D-X(2@`F*"4`7D@J`"8(+``&T`(`*
M@A!`"8<I<`6F!P`!A3%P&XDK,!Z$$(`#@S,P`H0(@!>&$$`$@@3``I@(P!>F
M"$`7@A,`"H8+``J""4`!D`(`#(4T\!N"$$`#ARSP!8(&P`&)*7`>A!"``XLQ
M<`*$"(`7BA%`!((`0`+(7Z0OB@E`%Y((0!>"$4`,A@E`#((,P`&X`0`%A3)P
M&X(00`.'*G`%@@:``8DL\!Z$$(`#AS3P`H0(@!>"`$`"A!#`!)@(0!>("(`7
MBAD`!;H'0`2%*S`%BAE`"8,S,!N0`@`%ARIP'H(00`*%,G`"@@A`%Y`"``&"
M$(`#D@A`%Y`*`!>$&D`$M@/`"=Y?I`>#,C`;AAB`#(4J,`6(!P`#ARLP'H(0
M0`*%,S`"@@A`%X(!``&$$(`#B@A`%X@(@!?"7Z0?A!D`";@`0`2&&(`(@S%P
M&[H'0`.%*7`%ARHP'H(00`*1,C`"@@A`%Y`2``.Z!T`!QE^D%Y`*`!>Z#T`7
MA!H`!+0`P`B#-W`;AAB`!84O<`6(!L`#AREP'H(00`*%,7`"@@A`%X(!``&$
M$(`#B@A`%X@(@!>0&0`(H`0`!(4I<`60&@`=@S%P&Y('``B'+W`>@A!``KLW
M<`*""$`7NA=``X("0`&Z#T`7D@A`%X,R<!N$'T`$R%^D#X88@`6%*G`%N`$`
M'8(00`*(!H`#A3%P`H((0!>'*7`>@@$``800@`.*"$`7@S%P&X@(@!>Z&0`=
MM@/`!-Y?H^>%*7`%NA]`"8(00`*@!``=ARIP'H((0!>%,G`"H`0``8(0@`.@
M#``7D@A`%\)?H_^$&D`$N@!`"888@`6#-#`;B`<``X4L,`6'*7`>@A!``H4Q
M<`*""$`7A!"``X(!``&("(`7B@A`%X09``FD!(`$@S%P&X88@!"%*7`%D@;`
M`X<L,!Z"$$`"H30P`H((0!>@%``#@@)``<9?H_>@#``7D@A`%X0<``2X`,`0
M@S)P&X88@`6%*G`%B`=``X<I<!Z"$$`"A3%P`H((0!>"`0`!A!"``\A?H^^0
M"$`7B@B`%Z`90!"Z`0`%A2HP!:`<``F#,C`;I`2`$(<J<!Z"$$`"A3)P`H((
M0!>D!(`!@A"``X@(0!>D#(`7A!D`!;8#P`3>7Z/'@S2P&X88@`B%++`%B@<`
M`X<J,!Z"$$`"A3(P`H((0!>$$(`#@@%``8H(@!>0"$`7A!E`!*($0`6#,C`;
MAAB`$H4J,`6(!T`#ARRP'H(00`*E-+`"@@A`%X(!``&D%(`#B`A`%Z0,@!?"
M7Z/?A!R`!;H`0!*&&(`(@S$P&XH&P`.%*3`%ARHP'H(00`*%,C`"@@A`%X00
M@`."`4`!B@B`%\1?H]>0"$`7@S(P&Z090!*X`(`%I!R`!(4J,`6B!$`2ARDP
M'H(00`*%,3`"@@A`%Z($0`&"$(`#QE^CSX@(0!>B#$`7A!D`!;8`P`2#-'`;
MAAB`"(4L<`6*!T`#ARHP'H(00`*%,C`"@@A`%X00@`."`4`!B@B`%Y`(0!>$
M&4`$J`4`!8,R,!N&&(`1A2HP!8@'``.'+'`>@A!``J,T<`*""$`7HA1``X(!
M``&B#$`7B`A`%X0<0`6Z`\`1@S$P&X88@`B%*3`%B@;``X<J,!Z"$$`"A3(P
M`H((0!>$$(`#@@%``8H(0!>0"(`7@S%P&Z(:`!&%*7`%HAQ`!((00`*H!0`1
MA2DP'H((0!>',3`"J`4``<A?H[>"$,`"J`T`%X<M,`62"$`7A34P&X(:0`B"
M&$`%A!"``YX'0`&$"(`7@REP'IX#P`*',7`"G@O`%X0#P`3>7ZA_AA#``8((
M@!>*",`7PG/``,);X`C$6^`0QEO@&*@%``'(6^`@@@%``J@-`!>$`D`#@@A`
M%^ASX`B&`@`$PG/@$(0(@!>"",`7Q'/@&,)SX""!S^`(`0```#!H``0!````
M`0````$```"=X[]`"L8`!`,`"#*!S^`(D!`@`.988Q@"_/_]`0```,).``"$
M&&`]@*```89`(`"`H``"@D`@`("(P`$"0``.E!`@`(@0`!B(`2`!PDD``(08
M8#V`H``!AD`@`("@``*"0"``@(C``3)/__F(`2`!E"$`&.!<P``"]#_EI3J@
M`!!H``:B$``3H@1@".!<0``"]#_?`0```)`0`!"2$``80`0AZ)00`!(J^C_Y
MH@1@",),@!"`H&`]$D__])`$@!"")$`3@SAP`\(F0`"!Q^`(D>H@`3!H``,!
M`````0```)WCOS"@!Z?KD!``&)(0`!!____$(P`(,@+"``["1Z?KQ%QC&(,H
M<`.$`$`"A`"@",)8@``*^'_^PG"_^)`0`!A___^XDA``$`KZ/_;"1Z?K@<_@
M"`$````!`````0```)WCOS"0$``8?___KI('I^N!Q^`(D>@`"`$````!````
MG>._0#$`""["!B.\@*!__P)```01``05@<_@"-!"([Q____PD!(C,`+"``>"
M$"``PDH``("@8``22``&@AA@,((0(`#")B.\@<_@"-!"([R`H``!@D`@`!!O
M__S")B.\G>._0#$`!`Z0$#__LA`@`$`$(<RP%B#@$(0BZH'H```!````,&@`
M!P$````!`````0````$````!`````0```)WCOT`#``@Q(P`(,<988M`%``@Q
M$0`$%LI<8I"0$B,0DA`@`,)8X"#&"**HR%E@"(,P<#>#*&`'A@C@?X(00`/"
M,2`"Q%QBD$`$(<[@6*`(T'0@*`,`"#&*$"``R%QBD,988N`#``@QQ%D@",9P
MH##$7&*0PEAB@`+`0`/$6*`(REA@J,IPH#C"7&*0Q%A@",!PH$#"7&*0Q%A@
M"`,`"#'`<*`@R%QBD,988MC$62`(QG"@2('/X`@!`````0```)WCOL`"Q@!)
M`0```,).``"`H&``$D``!`$```"!S^`(`0```$`$(>^0$``8`O(__*00``@#
M``05!0`$%:808T`#``05J!"C2*P08U"J!Z=W+P``/#L``!!`!"*"D!``$I(0
M`!,"P@`KH@(@"$`$(A60$``1`OH_^9(0`!1`!"(1D!``$0+Z/_4!````0`0B
MO9`0`!B@$``(0`0BNI`0`!&0`@`0D`(@`D`$(E:1.B``DA``%I00`!B6$``1
M0`0BR:`0``B0$``00`0AOI(0`!6`HC__`D``!L(7IW^""$`7@*!`'0)``!,!
M````0`0AE9`0`!!`!")CD!``$$`$(EF0$``2DA``$PKZ/]FB`B`(0`0BI)`0
M`!)`!"'*D!``&('/X`@!````@<_@"`$```!___^TD!``$!!O_^\!````G>.^
MP)('IW=`!"$&D!``&("B(``20``/QA>G?P,``#P%```0A@C``0,``"B$&,`"
MAAC``8"@``*(8#__@*```X)@/_^`D0`!$D``!9`0`!BP$"``@<_@")$Z(`!`
M!"&!DA`@`H"@``BP8#__@<_@")$Z(``P:``#`0````$```"=X[\PPDY``((8
M8#V`H``!A&`__[(&0`)`!")JD!``&:80``B2!Z?K?__^UI`0`!@"P@!6H!``
M"$`$(F(I``@R@S3@`("B``$Z:`!!P@Y``,).```0:``#B!``&,))``"$&&`]
M@*```89`(`"`H``"@D`@`("(P`$R3__YB`$@`9`$X`+@!Z?KD"(`&.)=(QBA
M+#`#D`(`!$`$(>J1,B```L(`8]!T`!'$!Z?K`P`(,LA88QC&#@``A2BP`\A9
M``*#*.`8@SA@&("@8``"0``2QBD``("@8#T"0``0@A`@/1!H``6&!B`!@*!@
M/0)```N"$"`]Q`C``(@!(`&&`.`!@RB@&(,X8!B`H&``$D__]\0I``""$"`]
MA`$@`<(I``#"#D``L@9@`<(H@`"#*&`8@*!@`!)/__N$`*`!L!`@`('/X`B1
M.B``P@Y``+(&8`'"+```@RA@&("@8``"1__XH`0@`<(.0`"R!F`!PBP``(,H
M8!B`H&``$D__]*`$(`$0;__PL!`@`"D`"#*B$"``T%TC&,):```"P$`*DA`@
M$(00``B$`*`(PEB```KX?_ZB!&`!@@1@`H,X8`"3*'`#!0`(,<(`HO"`H&``
M$D@`$H(0(`&0$``)0`0AFL(@HO`"P@`3I!``"(,\8`#272,8H2AP`T`$(7.4
M$``0Y'4C&,)=(QB"!``!P'!@"!!O_Y'B)Z?K0`0@JP$```"#/&``T'4C&`KZ
M/_>A*'`#L!`__X'/X`B1.B```0````$```"=X[\``P`$%@4`!!7`=Z?GZEAC
MF`,`!!6$$*-P@A!C:,1WI\<%``05PG>GOP,`!!6$$*.`@A!C>`<`!!7"=Z?/
MAA#C6,1WI]<#``05!0`$%8(08YC&=Z>WI!```Z@0HZC"=Z??$&@`!Z8'I[]_
M__]5D!``$N1<P``"Q(`FI@3@"'___H"0$``2HA``"`+R/_B2$``8PDH``("@
M8``"3__T`0```$`$(/^2$``8*OH_\^1<P`!`!"&SD!``&*`0``A`!"&PD!``
M%:`$``A`!"&MD!``$:`$(`%`!"%*D`0`")(0`!24$``8EA``%9@0`!%`!"&\
MH!``")`0`!)___\QDA``$.1<P``*_+_>I@3@"('/X`@!`````0````$```"=
MX[\0`P`(,1,`!!:H$&)`DA)C:)00("*0!Z?%PET``,)WI^>"$"``0`0A/B<`
M!!41``05D!(CL'___C(E``06$0`$%2,`!!60$B/`?__^+2$`!!81``05?__^
M*I`2(\@1``05?__^)Y`2(]A___XED!3CX!$`!!5___XBD!(C\'___B"0%*``
M?__^'I`48S!___X<D!0@$!$`!!9___X9D!(@(!$`!!9___X6D!(@,!$`!!9_
M__X3D!(@0!$`!!9___X0D!(@4!$`!!9___XED!(@8`+"``22$``(?__^\9`4
M(!`1``06?__^'I`2('@BP@`'$0`$%I(0``@1``06?__^Z)`2()`1``06?__^
M%9`2(*`"P@`0DA``"'___N&0%*``$P`$%I`4X^!___[=DA)@V,)?I^?$70``
M@AA``H00(``*P$`9`0```('/X`@!````$0`$%G___@*0$B"P`L(`!I(0``A_
M__[.D!1C,!!O_^X3``06$P`$%I`'I]:2$F#(0`0?MY00(`HJ^C_G$P`$%I`4
M8S!___["D@>GX!!O_^(3``060`0A!@$````!````,&@``P$````!````G>._
M0$`$(.^P$"``0`0@E9$R(``JR@`"\%H``('/X`@!````,&@`!P$````!````
M`0````$````!`````0```)WCOT`BQ@`(,0`$%<(.``"A*&`8@*0@`!)```4!
M````,0`$%1"$'Y>1[B-`0`0A#9`0`!B0`@`8E`(__X"F``H:8``5"P`$%L)9
M8Y#0"C__Q`A``)$J(!B)**`8@*$`"!)``"B#.B`8$&@`!X80``&#*&`8A3A@
M&("@@`,20``AD!```90"O_^`I@`**F__^<(*@`"`HH`8$F``"L998Y#P66.0
MA3P@&,).``"`H(`!(D?_W3$`!!40A!]R@>@``)0"O_^`I@`*.F``")0B@!C$
M2H``PDC``("@@`$B3__ZE`*__Y0B@!B"`J`"@*!D``A@`!2@$"``@<?@")'H
M`!`0:``#A3D@&)$J(!B#.B`8@*"``0)'_^&`HH`8E`*__X"F``HJ;__YT`J`
M`("B@!@B;__=\%ECD!!O_^+&66.0(0`(,9(0`!B0%"+X0`0?K90"H`$0;__I
MH!0B^`$```"=X[]`?___IY`0`!A___<-`0```'___8.B$``(@*(@``)```@!
M`````L8`!@$```#"3@``@*!@`!)```03``06@<_@"`$```"0$``10`0?]9(2
M8."`I$`($F__^@$```!___W(@>@```$````P:``%`0````$````!`````0``
M`)WCOS"0!ZA_D@>HA_)WJ(>4!ZB/]'>HCT`$'Y+P)ZA_`P`(,<1(8HB`H*``
M`D``80<`"#'"!ZA_Q`CBB8(`8`61.&``A!"@`P;"`&O$*.*)T'>GYX(0``#1
M'Z?GPG>G[X(0(0^5H!$(T1^G[X,H<#;"=Z?OD:*(2-4?I^^!J@K*+4@`<!$`
M!!9`!""ND2HP`\I?J(<#``@RAA`@!-!P8Q`#``@REA``",190`":`C_XU`>H
M?\1R```%``@8QB!C"`,`!!:$$*`8@A!@\,)R(`B`HJ`!`P`$%L1R(!""$&#X
M!$``"\)R(!B($"`!AA`@",190`."`L`#B`$@`88`X`B`HH`$%$__^\1P8!B"
M`J`$-0`(,H,X8`#07J+XE`*@`X,H<`,3``05DA)B()@0(`#`<T`!0`0?&Y4Z
MH`"PDB```D``1`$```!`!!^VT%ZB^!$`!!5___T+D!(C\`+"``DS``@RT%ZB
M^$`$('ZQ/B``0`0@9`$```"!S^`(`0```-!>8P`BP@`W$0`$%G___WT!````
MT%ZB^$`$('*Q/B``0`0@6`$```"!S^`(`0```$`$']P!`````P`(,@+"`#'0
M<&+X0`0>UP$````#``@Q!P`(,<`H8C#"!ZA_Q`CBB8(`8`61.&``A!"@`P[Z
M/YG$*.*)@S(P`80*(`&"$$`"PG>GY]4?I^>"$```PG>G[X(0(0^1H!$*@RAP
M-I6B"$C1'Z?OPG>G[Y&BB$C5'Z?O@:H*RAU/_Y4!````$0`$%A,`"#&0$B#H
M0`0>9I(28K!`!!\TT%ZB^!!O_[RP$``(?__\R)`2(``"\C^_T'9C`'___T0!
M````$&__R-!>HOA`!!^0D!`@`0$````P:``%`0````$````!`````0```)WC
MNL`#``@Q$0`$%KH08D"0$B``PE]``,)WI^>"$"``?__\L`$````#``06HA``
M".!88Y"0$``80`0?,I(0`!`"P@`.`0```!$`!!:2$``8?__]=)`2(##"7Z?G
MQ%]``((80`*$$"``"L!`7@$```"!S^`(`0```$`$']J0$``8`P`$%J00``CF
M6&.8D!``&4`$'M22$``3`O(_[+(0``@#``05J`2@`:H08T`#``05K!!CJ*0'
MH^>N!Z-O.0``/#<``"#"3D``@*!@``+$0`>S9$`5D!``$4`$'Q*2$``9`L(`
M+0$```!`!!^^D!``&8,Z(`#(3```B@(__X<Y8`""!D`!Q$A__X"@@`0"2``%
MA@#`&1!H``V"!0`(B@(__\`HP`"0$``%P@C__\1,``"#*&`8@SA@&("@0`("
M3__XA@#__X(%``B`H&/_%$?_OY00`!F6$``0F!``&)(0`!9`!!^XD!``$I`0
M`!)`!!ZMDA``%X"B(``20``&PA>C=X((0!R`H$`;`D``"9`0`!*0$"``0`0>
MDY(0`!,*^C_*LA``"!!O_ZH1``060`0>E9(0(`&`HB``,D__]Y`0(``1``06
MDA``$G___1:0$B`P0`0>#)`0`!(0;_^@L!``"$`$'U@!`````0```#!H``4!
M`````0````$````!`````P``(((8?9"=XX`!`P`(,04``""Z$&)`A!B_",)?
M0`#"=Z?G@A`@`(H'I_^H!Z?OB`4``H8!0`(Y``06`P`$%L!Q(!`%``06@A!A
M`,)P__"$$*$(D!<@`'___"+$<2`(K!``&`+"``:@$``(PDH``("@8``20`#(
M`0```'___C&@$"```P``(*80``B"&'\(`L(`B:0%``'"#,``@RA@&("@8``"
M0``;"P`(,8@0`!,;``@QA3A@&("@H``&0``-P@%BF("@@`$62``+@A`@7X,X
MH`#&6V*@@RAP`X(`0`/$6&!`@(BE`#)H``6(`2`!@A`@7\(I``"(`2`!P@D`
M`(,H8!B`H&``$D__[(4X8!@#```@B@>G_X(8?M@)``06A@4``80!0`$#``06
MB!$@D,APO_""$&$@PG#@"`4`!!8#``06A!"A*,!PX"B"$&$PPG#@&*(`X`@#
M``06Q'#@$((083@0:``%PG#@(,A<0``"P0!@H@1@"'__^]J0$``$`O(_^Z`0
M``C"2@``@*!@`")/__C(7$``?__\@@$```"`HB``(D__\\A<0`!`!!V5D!``
M$`+*`%"D$``(0`0?"9`0`!*@$``(0`0?!I`0`!.0`@`0D`(D!*,Z(`!`!!ZA
MD!``$0,`!!83``06[EACD!D`!!:2$F%0E!``$I@3(.":$``3EA``%T`$'PZJ
M$``(D!``%4`$'HN2$"'`@*(__P)``&,#```@D!``%8(8?F"D!0`!0`0=8Y(0
M`!*`HB``$D``"`4``#S"%*`(!P``$(((0`*`H$`#`D``:0$````#``@Q$P`$
M%M1=@`#06&+(DA)A\)80`!5`!!TZL!`@`,)?I^?*7T``@AA`!8H0(``*P$"Y
M`0```('/X`@!````0`0=6`$```"F$``("O3_>Z`$(`C07``2`L(`K0,`!!9_
M__N(`0````+R/_D!````PDH``("@8``21__R`0````+\__6@!"`($&__;<(,
MP`"D$"``!P`$%@4``"#:2.%`A!B_((('I_^(!0`"B@!``@,`!!6&$.%`P'$@
M$((08T#&<7_PHA```\)Q(`B`HV```D?_HZ`!(`A___P:D!``$8"B(``20``0
M`0````KTOYP!````XEP```+T?YD!````PDQ``("@8``"1_^5H`0@"'___`R0
M$``1@*(@``)/__0!````0`0='Y`0`!$0;__PI!``"'___+,!````0`0=&9`0
M`!`0;_^WL!``"$`$'<4!````P@(``("@8!$"3_^;`P``(`,`"#'B78``L!`@
M`$`$';S@6&+(V$(``!,`!!:0$``0DA)A8)00`!%`!!S=EA``%1!O_Z,!````
M0`0>0>`$H`R`I``($D__EP,`"#'"%*`(@@AA_X"@8<`23_^2`P`(,4`$'@^0
M$``1L!``"!$`!!5___LKD!(C>"+"``GB78``0`0<[^!=@`"2$``(?__^;)`0
M`!`"P@!)HA``"$`$'F"0$``1@*(@`Q1``2>@$``(?__[(P$```"`HB``$D@`
M"1,`!!:0$``10`0=S9(0(`"`HB``,D``.ZTZ(``3``06$0`$%9(28-A___O=
MD!(C,$`$'CN@$"```P`$%A,`!!::$&,0DA)AR)DZ(`"4$``5D!``&)80`!=`
M!!Y9HA``#0,`!!80:``2I!!AV$`$'70!````P@(``("@8!$20``2`0```$`$
M'B:@!"`!XG.HKY(0`!*9.B``E!``%9`0`!B6$``70`0>1IL\(`"0$``80`0=
MPY(0(<"`HC__`D__[`$```!`!!WFD!``%9`7(`!___NSDA``&'___$&0$``8
M$&__1P$````0;_[IIA!A&$`$'?,!````$&__N>)=@``A```@DA`_[I00(`*@
M'#\X0`0=4Y`0`!:B!0`0D!``%I00(`9`!!X>DA``$80'I_^"`(`0Q`A_\("@
MH``20``'D!``%L(,8`&`H&!#(D``]\(,8`*0$``6DA`@`)00(`!`!!T_-0``
M(,!WIT^$'K\X`QG12,!WIU>V!0`"@A!C`<)WIR<%._-J`R8NM\`GIY^$$*.)
M@A!@_L1WIR^$$#__PG>G-P,$#)6S,+`@!3#TN((08':$$*'PPG>G/Z@'IR?$
M=Z='D!``%I(0`!M`!!WTE!``&J*2(``$0``ZQ%^G3X<\8`"#*/`#@@!``H@(
M0!F`H(`$"&@`!,1?IU>$`*`!Q'>G5X,P\!W0!Z>?H!``&X(`@`'(=Z=/I`>G
M7X"B(``"2``+PG>G5Q!H`!&"$"!`E!`@0)`0`!)`!!UYH@1_P)`0`!1___0N
MH`0@0("D8#\43__XDA``$)`0`!)`!!UPE3Q@`!!O_]CB)Z>?DA``&X(@0`B@
M$``!@*1``:%D@!&1.B``ISP@`)`$@`A`!!UDE!``$\('IY^"!``!@*!@0!)/
M_\G")Z>?D!``%*(D0!!___03H`3`&Q!O_^:`I&`_0`0=!Y`0`!;@7Z=/XE^G
M5X,T,`.""&`_A3A@`(8`8`&$!0`"@A`_@("@X#@$2`"%PBB@.)$XX`"4$"!`
ME"*``Y`"`!25.J``DA`@`$`$'+20`B`X?__S^I`0`!3`=Z=?P'>G9\!WIV_`
M=Z=WP'>G?\!WIX?`=Z>/@S1P&,(OIY>0$``4A31P$,0OIYBH!Z>J@S0P&,(O
MIYND$``4AS1P".(OIYJF$"``A30P$.`OIYZB!Z?3@S0P",8OIYG$+Z><?__S
MW\(OIYW$7Z<G`P`$%L9?IR^@$&'`RE^G-YLPL!C87Z<_@S"P$-9?IT>),+`(
ME3#P&-HOI]/"+Z?4FS#P$(,P\`C(+Z?5Q"^GUHDQ<!B%,7`0U"^GU]HOI]B5
M,7`(PB^GV9,S,!C&+Z?:@S,P$,@OI]N',S`(Q"^GW(DR\!B%,O`0U"^GW9LR
M\`C*+Z?>TB^GW\(OI^#&+Z?AV"^GXL@OI^/$+Z?DVB^GY=8OI^;4#,`1D!``
M$I(0`!"F!.`!0`0=7Z0$H`*`I.`4,F__^M0,P!$3``06&P`$%L`OI]*2$F&P
MEA``%Y@0`!2:$V,0D!``&$`$'5*4$``5$&__$@$```"1.B``$P`$%I`"`!&2
M$F&@0`0<@I`"/_P*^C[5@*0@!`)```F"!#_\QDW``(,X8`""!$`!Q$A__X"@
M@`,23_[,`0```.!=H`@"]#[)`0```$`$'2*0$``0@*(@`PAO_L20!``($P`$
M%I`"/_Q`!!QKDA)AJ!!O_KZC>@00D3C@`)00(#B4(H`#D`(`%)(0(`"0`B`X
M0`0<,94ZH``0;_^'@S1P&("@8$$23_\+D!``%L(,8`.`H&!#$D__")(0(`#"
M#&`$@*!@2!)/_P64$"``P@Q@!8"@8$423_\!`0```)00(`)`!!P]DA`_QI(0
M`!&0$``60`0="900("D3``06&P`$%I`0`!B2$F&PEA``%Y@0`!&:$V,00`0=
M")00`!40;_[(`0```#!H``0!`````0````$```"=X[<P`P`(,:`'H^:B$&)`
MPEQ``,)WI^>"$"``0`0<T0$````3``06%P`$%I4Z(`"2$F)(EA+B6$`$'/*0
M$``0@*(@`!9```ND![_EL!`@`,)?I^?$7$``@AA``H00(``*P$`6`0```('/
MX`@!````D!``$)(0`!)`!!SRE!`D`*"2(``&3__SL!`@`)`$(`%`!!QDD3H@
M``+R/^VP$``(H3P@`)(0`!)`!!QNE!``$!!O_^C`+``80`0<D@$````!````
M,&@`!P$````!`````0````$````!`````0```((3P``0;__'`0````$````P
M:``$`0````$````!````G>._0!$`!!4M``@Q@A`@`9`2(^!___ECPBVBG`+"
M``8!````PDH``("@8#$B0`!PPDH@`7__^P,!````$0`$%I(0(`&0$B)@0`0<
M'I00(`L"P@`NI!`@`"<`"#+$6B`0P@3C"("@8`$$0``CZ%B@**(0(`@0:``-
M*P`(,M):(!!`!!O8D!``$`K"`!S$!.,(I`2@`<0$XPB"!*`!@*"``01``!:B
M!&`(D!``%)00(`!`!!QTDSR@``+"``_"76,0T%H``,0"(`R`B*0`$F__[.!8
M0!&2$"``0`0:VI00(`*2$``(0`0;OY`0`!`B^C_JI`2@`<0$XPB"`+__@*!`
M$@)``$"`H*`!$0`$%I(0(`&0$B)H0`0;ZY00(`0"P@`.H!``",):(!`3``06
MDA)B<$`$&S306$``PEP@$-!80``#`!``Q`(@#("(@`$20``X`0```!$`!!:2
M$"`!D!(B>$`$&]B4$"`$`L(`"J(0``@1``06?__Y"Y`2(#`"P@`XDA``",)<
M8!!`!!L>T%A``!$`!!8#``@QP"VBG)`2(``A``@R?__X_\!P8C@"P@`DT'0C
M`$`$&].2$"'`@AH@$8"@``B&0"``@*```81`(`"`B,`"`D``!("B/_\20``L
MESH@`('/X`@!````@*!@``)/_Y01``06$&__CP$````$1__"H!`@`9`0`!1`
M!!JUH`0@`<($XPB`H$`0-$___)`0`!00;_^Z$0`$%D`$&K4!````$&__R1$`
M!!8E``@R?__\H-!<HQ`*P@`@T'0C`!$`!!9`!!IKD!(B@'___V$!`````L(`
M$:`0``C"7&`0DA``"$`$&N/06$``0`0;R9`0`!`0;__$$0`$%@,`"#+47",`
MQ%AC$!$`!!:0$B+00`0:6-)8@``%``@RPEQ@$,98HQ#06$``0`0:TM)8P``0
M;_^U$0`$%L)<8!#06$``Q`(@#("(I``"8``3DA`@`-!:(!!`!!I?TERC$,)<
M8!"F$``(Q%RC$-!80`#"`B`,@(AD``)@``S@6(``U%H@$!$`!!:2$``0ESS@
M`$`$&CF0$B*H0`0:1Y00(`(0;__N`0```)00(`)`!!I"DA`@`!!O__24$``(
M,&@`!@$````!`````0````$````!````$0`$%A,`"#`5``06D!(C&)(28H"4
M$J,X@A/``!"$&JD!`````0```#!H``8!`````0````$````!`````0```)WC
MOT`U``06,0`$%K06HQ`S``04L!8C2+(68H"V$``:?___Z+@0(``0A!I6@>@`
M``$````P:``#`0````$```"=X[]``P`(+X(08>#$6'_X@*"__P)@``B@`'_X
MG\"``*`$/_C$7```@*"__Q)O__P!````@<_@"`$````!````G>._0('/X`@!
M````,&@`!0$````!`````0````$```"=X[]`?__QKP$```"!Q^`(@>@`````
M```D1G)E94)31#H@<W)C+VQI8B]C<W4O<W!A<F,V-"]C<G1I+E,L=B`Q+C$N
M,S8N,2XT+C$@,C`Q,"\P-B\Q-"`P,CHP.3HP-B!K96YS;6ET:"!%>'`@)```
M4$%27T-,14%.`````````"X`````````+BX````````E<R\E<P```$Q$7TQ)
M0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!
M4EE?4$%42`````````!32$Q)0E]0051(````````)7,E<R5S``!015),-4Q)
M0@``````````4$523$Q)0@!015),-4]05```````````4$523$E/``!005)?
M24Y)5$E!3$E:140`4$%27U-005=.140``````%!!4E]414U0``````````!0
M05)?1$5"54<`````````4$%27T-!0TA%`````````%!!4E]04D]'3D%-10``
M``!005)?05)'0P``````````4$%27T%21U9?,````````%!!4E]'3$]"04Q?
M1$5"54<``````````%!!4E]'3$]"04Q?5$U01$E2`````````%!!4E]435!$
M25(```````!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````
M````4$%27T-,14%./0```````#$`````````<&%R+0`````E<P```````"UE
M````````+2T```````!54T52`````%5315).04U%``````````!365-414T`
M`%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````+W9A<B]T;7`O````
M`````"5S)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````<&%R;```
M```N<&%R`````"5S)7-C86-H92TE<R5S```E,#)X`````"5S)7-T96UP+25U
M)7,````E<R5S=&5M<"TE=2TE=25S```````````E<SH@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R
M971R>2!Y;W5R(&]P97)A=&EO;BD*````````+W!R;V,O)6DO)7,``````&9I
M;&4`````05)'5@`````8`````````'!E<FP`````,`````````!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&5X96-U=&EO
M;B!O9B`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H``````````$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``````<&5R
M;'AS:2YC`````````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````#H`````````
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````````````````
M$%E(```````06V`D1G)E94)31#H@<W)C+VQI8B]C<W4O<W!A<F,V-"]C<G1N
M+E,L=B`Q+C$N,S8N,2XT+C$@,C`Q,"\P-B\Q-"`P,CHP.3HP-B!K96YS;6ET
M:"!%>'`@)```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````06Q``````````````````(+WP(R$O=7-R+V)I;B]P97)L
M"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@
M("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K
M86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E
M(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T
M.PH*(VQI;F4@,34X"@IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F
M:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER
M92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@
M(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO
M=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@("`C($1O;B=T(')E
M;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O
M=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R>6EN9R!T;R!S=&%R="X*"B`@
M("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*("`@
M("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H
M87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S
M:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA
M="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@
M("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@
M:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@("`@("`C($1O;B=T(&1O(&%N
M>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@
M=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F(&-L96%N:6YG('1H:6YG<R!U
M<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@
M("`@("!414U03$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@
M/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@
M("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P
M+`H@("`@("`@("D["@H@("`@("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX
M/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?
M=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@
M("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@
M("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@("`@("!M>2`D8VUD
M(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@
M("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@
M("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@+B`D=&UP+3YF:6QE;F%M92D[
M"B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L
M('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'
M5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P
M("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@
M,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["B`@("!F
M;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O
M7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*
M;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-
M4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]
M?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@
M(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z
M("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*
M"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L
M960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*
M("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PH*("`@(",@0VAE
M8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@
M("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM
M;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*
M("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E
M<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E
M860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B
M3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A
M=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT
M<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q
M=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@
M("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D
M8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M
M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>
M*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H
M9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD
M+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M
M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@
M("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@
M<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*
M("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]
M"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N
M9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@("`@("`@("`C('-H
M;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D
M9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@
M("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@
M("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*
M("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@
M)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L
M;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*
M("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@
M;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T["B`@("`@("`@?0H@
M("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@
M("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D
M=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@
M(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME
M>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2![
M"B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*
M("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D
M969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D
M24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*
M("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F
M:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@
M("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R
M;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M
M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M
M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@
M("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T
M("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L
M("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@
M("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE
M(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<
M;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D
M(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R
M;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!
M4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R
M(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@
M("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@
M("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>
M3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@("`@("`@("`@(",@
M<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@
M("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@
M("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`C(%-K:7`@06-T
M:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@
M("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U
M<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@
M(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"([
M"B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@
M07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U
M="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["@ID96QE=&4@)$5.
M5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@
M<V5C=7)I='D@<')O8FQE;2D*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%2
M7T1%0E5'?3L*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL
M960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T
M87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H
M:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L
M:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@
M('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*("`@("`@("!V
M("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("`C(&EF('1H92!A<'`@:7,@:6YV
M;VME9"!A<R`B87!P;F%M92`M+7!A<BUO<'1I;VYS("TM<F5U<V4@4%)/1U)!
M32!`4%)/1U]!4D=6(BP*("`@(",@=7-E('1H92!A<'`@=&\@<G5N('1H92!G
M:79E;B!P97)L(&-O9&4@:6YS=&5A9"!O9B!A;GET:&EN9R!F<F]M('1H90H@
M("`@(R!A<'`@:71S96QF("AB=70@<W1I;&P@<V5T('5P('1H92!N;W)M86P@
M87!P(&5N=FER;VYM96YT(&%N9"!`24Y#*0H@("`@:68@*$!!4D=6(&%N9"`D
M05)'5ELP72!E<2`G+2UR975S92<I('L*("`@("`@("!S:&EF="!`05)'5CL*
M("`@("`@("`D14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["B`@
M("!]"B`@("!E;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*"B`@("`@
M("`@;7D@0&%D9%]T;U]I;F,["B`@("`@("`@=VAI;&4@*$!!4D=6*2!["B`@
M("`@("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N
M*BDO(&]R(&QA<W0["@H@("`@("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@
M("`@("`@("`@("`@("!P=7-H($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@
M("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@("`@("`@('5N<VAI
M9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("`@("`D;W5T(#T@)#([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@
M>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=S:71E)SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@
M("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@("`@("`@)'%U
M:65T(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)TPG*2!["B`@("`@("`@("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@
M("`@("`@("`@("1C86-H95]N86UE(#T@)#(["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@("`@(&EF("AM>2`D
M8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@("`@("`@9&5L971E
M("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@("`@("!I;FET7VEN8R@I
M.PH@("`@("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@
M("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*
M("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@
M0$%21U8["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!U;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PH@
M("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@
M?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T
M*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&
M24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/
M.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*
M("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@
M("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\
M)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@
M("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E
M860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D
M;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS
M.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<[
M"B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U
M="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN
M960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE
M("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I
M92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")0
M2UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@
M(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@
M("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].
M3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@
M("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E
M9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E
M96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*
M("`@(&EF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>
M*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W
M+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[
M)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V
M86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?
M(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[
M)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G
M('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*
M("`@('T*("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F
M.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*
M("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y
M.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@
M("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*
M"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H
M)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@
M("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,[
M"@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@
M(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I
M;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*
M("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P
M97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE
M87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T
M)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL960N("TM(%-T969F96X*
M("`@("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@
M)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I
M;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R
M:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@("`@("`@("!F
M;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@("`@(&EF("@D
M;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@
M("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@("`@("`@("!L
M87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@
M("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@
M("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`H
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R
M:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL
M92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@
M("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B
M*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@
M("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@
M(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@
M("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!O
M<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE
M.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@
M("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@("`@("`@("!C
M;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@
M("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@("!005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ
M<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P
M<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@
M*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D[
M"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O
M=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H
M95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@
M("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@
M("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@
M1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@
M("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D
M;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92![
M"B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T
M(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L
M;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C
M86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*
M("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@
M)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@
M("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K
M*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M
M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM
M;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*
M(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI[
M"B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I
M>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N
M9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!0
M05(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@
M('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I
M9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN
M9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&
M:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O
M<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D
M:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!
M4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P
M;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF
M:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE
M(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H
M;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I
M;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@
M("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C
M=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D
M;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@("`@("`@("`@
M(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M
M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@("`@
M("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@
M("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@
M(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N
M+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R
M96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@
M($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@
M)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I
M<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I
M<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@
M=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A
M=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT
M;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ
M4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I
M9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I
M;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!
M<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2
M.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0["B`@("!R97%U:7)E(&%T=')I8G5T97,["B`@("!E
M=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R
M('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A
M;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V
M86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!]
M.PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@
M;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!
M4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A
M<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@
M/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D
M<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R!D969I
M;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@
M;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O
M97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF
M("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@
M("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@
M("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S
M97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM5
M4T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N86UE
M(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#
M;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER("1S
M=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@
M("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@
M("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L
M(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%
M(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@
M("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@
M("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY("1C
M='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M
M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@
M("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I
M9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U
M;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@
M("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M
M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A
M;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T
M(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO<V4H
M)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1%
M3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@("1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D
M:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C
M*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA
M;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL
M96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@
M?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE
M*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG
M+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@
M<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@
M:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S971?
M<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@
M)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*
M"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2![
M"B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@
M("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@
M("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER
M("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@
M>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#
M;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA
M<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@
M("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@
M("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE
M('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M
M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C
M(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD
M969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@
M("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ
M1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D
M0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6
M>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*
M("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"
M54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D
M96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U0
M1$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G
M+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`]
M(")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@:68@
M*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%27T-,
M14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!
M3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C
M;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%2
M7T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\[
M"B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970["B`@
M("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*
M("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*
M?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S
M:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]
M+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4
M:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E
M(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L
M.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H
M(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE
M.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%
M4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%
M4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2
M(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q,0H*7U]%3D1?7PH`````
M_____P````````````````````$``````````0`````````!`````````C<`
M`````````0````````)!``````````$````````"3P`````````!````````
M`EP``````````0````````*```````````\````````#W@`````````,````
M```0'&@`````````#0``````$%;```````````0``````!`!P``````````%
M```````0#P``````````!@``````$`3X``````````H````````%"@``````
M```+`````````!@`````````%0````````````````````,``````""^````
M```````"````````!;@`````````%``````````'`````````!<``````!`6
ML``````````'```````0%3``````````"`````````<X``````````D`````
M````&`````!P```!``````````$`````<````0`````````"`````&____X`
M`````!`4X`````!O____``````````(`````;___\```````$!0*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M__________\``````````/__________````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````P``@#!O_^<!````
M`0````$````!`````0````$````#``"@,&__WP$````!`````0````$````!
M`````0````,``,`P;__7`0````$````!`````0````$````!`````P``X#!O
M_\\!`````0````$````!`````0````$````#``$`,&__QP$````!`````0``
M``$````!`````0````,``2`P;_^_`0````$````!`````0````$````!````
M`P`!0#!O_[<!`````0````$````!`````0````$````#``%@,&__KP$````!
M`````0````$````!`````0````,``8`P;_^G`0````$````!`````0````$`
M```!`````P`!H#!O_Y\!`````0````$````!`````0````$````#``'`,&__
MEP$````!`````0````$````!`````0````,``>`P;_^/`0````$````!````
M`0````$````!`````P`"`#!O_X<!`````0````$````!`````0````$````#
M``(@,&__?P$````!`````0````$````!`````0````,``D`P;_]W`0````$`
M```!`````0````$````!`````P`"8#!O_V\!`````0````$````!`````0``
M``$````#``*`,&__9P$````!`````0````$````!`````0````,``J`P;_]?
M`0````$````!`````0````$````!`````P`"P#!O_U<!`````0````$````!
M`````0````$````#``+@,&__3P$````!`````0````$````!`````0````,`
M`P`P;_]'`0````$````!`````0````$````!`````P`#(#!O_S\!`````0``
M``$````!`````0````$````#``-`,&__-P$````!`````0````$````!````
M`0````,``V`P;_\O`0````$````!`````0````$````!`````P`#@#!O_R<!
M`````0````$````!`````0````$````#``.@,&__'P$````!`````0````$`
M```!`````0````,``\`P;_\7`0````$````!`````0````$````!`````P`#
MX#!O_P\!`````0````$````!`````0````$````#``0`,&__!P$````!````
M`0````$````!`````0````,`!"`P;_[_`0````$````!`````0````$````!
M`````P`$0#!O_O<!`````0````$````!`````0````$````#``1@,&_^[P$`
M```!`````0````$````!`````0````,`!(`P;_[G`0````$````!`````0``
M``$````!`````P`$H#!O_M\!`````0````$````!`````0````$````#``3`
M,&_^UP$````!`````0````$````!`````0````,`!.`P;_[/`0````$````!
M`````0````$````!`````P`%`#!O_L<!`````0````$````!`````0````$`
M```#``4@,&_^OP$````!`````0````$````!`````0````,`!4`P;_ZW`0``
M``$````!`````0````$````!`````P`%8#!O_J\!`````0````$````!````
M`0````$````#``6`,&_^IP$````!`````0````$````!`````0````,`!:`P
M;_Z?`0````$````!`````0````$````!`````P`%P#!O_I<!`````0````$`
M```!`````0````$````#``7@,&_^CP$````!`````0````$````!`````0``
M``,`!@`P;_Z'`0````$````!`````0````$````!`````P`&(#!O_G\!````
M`0````$````!`````0````$````#``9`,&_^=P$````!`````0````$````!
M`````0````,`!F`P;_YO`0````$````!`````0````$````!`````P`&@#!O
M_F<!`````0````$````!`````0````$````#``:@,&_^7P$````!`````0``
M``$````!`````0````,`!L`P;_Y7`0````$````!`````0````$````!````
M`P`&X#!O_D\!`````0````$````!`````0````$````#``<`,&_^1P$````!
M`````0````$````!`````0````,`!R`P;_X_`0````$````!`````0````$`
M```!`````P`'0#!O_C<!`````0````$````!`````0````$````#``=@,&_^
M+P$````!`````0````$````!`````0````,`!X`P;_XG`0````$````!````
M`0````$````!`````P`'H#!O_A\!`````0````$````!`````0````$````#
M``?`,&_^%P$````!`````0````$````!`````0````,`!^`P;_X/`0````$`
M```!`````0````$````!`````P`(`#!O_@<!`````0````$````!`````0``
M``$``````````""[R````````````"1&<F5E0E-$.B!S<F,O;&EB+V-S=2]C
M;VUM;VXO8W)T8G)A;F0N8RQV(#$N-BXR+C$N-"XQ(#(P,3`O,#8O,30@,#(Z
M,#DZ,#8@:V5N<VUI=&@@17AP("0`)$9R965"4T0Z('-R8R]L:6(O8W-U+W-P
M87)C-C0O8W)T,2YC+'8@,2XQ-RXQ,"XQ+C0N,2`R,#$P+S`V+S$T(#`R.C`Y
M.C`V(&ME;G-M:71H($5X<"`D`$=#0SH@*$=.52D@-"XR+C$@,C`P-S`W,3D@
M(%M&<F5E0E-$70``1T-#.B`H1TY5*2`T+C(N,2`R,#`W,#<Q.2`@6T9R965"
M4T1=``!'0T,Z("A'3E4I(#0N,BXQ(#(P,#<P-S$Y("!;1G)E94)31%T``$=#
M0SH@*$=.52D@-"XR+C$@,C`P-S`W,3D@(%M&<F5E0E-$70``+G-H<W1R=&%B
M`"YI;G1E<G``+FYO=&4N04))+71A9P`N:&%S:``N9'EN<WEM`"YD>6YS='(`
M+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP
M;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N9&%T80`N96A?9G)A;64`
M+F1Y;F%M:6,`+F-T;W)S`"YD=&]R<P`N:F-R`"YG;W0`+F)S<P`N8V]M;65N
M=```````````````````````````````````````````````````````````
M``````````````````````````````````````````L````!``````````(`
M`````!`!D`````````&0`````````!4````````````````````!````````
M```````3````!P`````````"```````0`:@````````!J``````````8````
M````````````````!```````````````(0````4``````````@``````$`'`
M`````````<`````````#.`````0```````````````@`````````!````"<`
M```+``````````(``````!`$^`````````3X````````"@@````%`````0``
M```````(`````````!@````O`````P`````````"```````0#P`````````/
M``````````4*`````````````````````0``````````````-V____\`````
M`````@``````$!0*````````%`H`````````U@````0```````````````(`
M`````````@```$1O___^``````````(``````!`4X````````!3@````````
M`%`````%`````@`````````(``````````````!3````!``````````"````
M```0%3`````````5,`````````&`````!```````````````"``````````8
M````70````0``````````@``````$!:P````````%K`````````%N`````0`
M```4``````````@`````````&````&<````!``````````8``````!`<:```
M`````!QH`````````!P````````````````````$``````````````!M````
M`0`````````&```````0'*`````````<H````````#H@````````````````
M````(```````````````<P````$`````````!@``````$%;`````````5L``
M````````%`````````````````````0``````````````'D````!````````
M``(``````!!6V````````%;8````````!1\````````````````````(````
M``````````"!`````0`````````#```````@8`````````!@`````````%O`
M````````````````````"```````````````AP````$``````````@``````
M(+O`````````N\``````````!`````````````````````0`````````````
M`)$````&``````````,``````""[R````````+O(`````````A`````%````
M```````````(`````````!````":`````0`````````#```````@O=@`````
M``"]V``````````0````````````````````"```````````````H0````$`
M`````````P``````(+WH````````O>@`````````$```````````````````
M``@``````````````*@````!``````````,``````""]^````````+WX````
M``````@````````````````````(``````````````!B`````0`````````'
M```````@O@````````"^``````````@@```````````````````!````````
M```@````K0````$``````````P``````(,8@````````QB``````````"```
M``````````````````@`````````"````+(````(``````````,``````"#&
M,````````,8P````````!/`````````````````````0``````````````"W
M`````0````````````````````````````#&,`````````%)````````````
M`````````0```````````````0````,`````````````````````````````
BQWD`````````P`````````````````````$`````````````
